/*----------------------------------------------------------------------------

      pcb2qbbs

      program reads pcboard.sys and writes a 2 record users.bbs and exitinfo
         for quickbbs

----------------------------------------------------------------------------*/

#pragma pack(1)

#include <stdio.h>
#include <process.h>
#include <fcntl.h>
#include <float.h>
#include <math.h>
#include <io.h>
#include <time.h>
#include <sys\types.h>
#include <sys\timeb.h>
#include <memory.h>
#include "pcbfile.h"
#include "qbbsfile.h"

// files

#define pcbfilename   "E:\\pcb\\pcboard.sys"
#define qbbsfilename  "users.bbs"
#define exitfilename  "exitinfo.bbs"

FILE *pcbfile,*qbbsfile,*exitfile;

// miscellaneous

flagtype	userflag;
char     graphics;
char     pcbstring[255];
char     userbaud[255], userlogon[255], username[255];
double   userlimit;

// records

sysinfotype	sysinfo;
timelogtype timelog;
usertype    user;
eventtype   event;
exittype	   exitrec;
pcbsystype	pcbsys;

void writeqbbsdata(void)

{
	short	i;
	char	x[25];
	char	today[9];
	float	allowed,logon,exited;
	struct tm	timenow,midnite,*newtime;
	time_t secsnow,secsthen;
	long	long_time;

// user file
	
	memcpy(&user.name[1],pcbsys.callernameplus2,27);
	user.name[0] = 27;

	memcpy(&user.city[1],"pcboard door",12);
	user.city[0] = 12;

	memcpy(&user.pwd[1],"",0);
	user.pwd[0] = 0;

	memcpy(&user.dataphone[1],"",0);
	user.dataphone[0] = 0;

	memcpy(&user.lasttime[1],"tt:tt",5);
	user.lasttime[0] = 5;

	memcpy(&user.lastdate[1],"dd-dd-dd",8);
	user.lastdate[0] = 8;

	if (pcbsys.graphicsmode[1] == '1')
		user.attrib = 0x0f;
	else 
		user.attrib = 0x07;

	for (i = 0; i < 4; i++)
		user.flags[i] = userflag[i];

	user.credit = 0;
	user.pending = 0;
	user.timesposted = 0;
	user.highmsgread = 0;
	user.seclvl = 10;
	user.times = 0;
	user.ups = 0;
	user.downs = 0;
	user.upk = 0;
	user.downk = 0;
	user.todayk = 0;
	user.elapsed = 0;
	user.len = 23;

	for (i = 1; i <= 8; i++)
	   user.extraspace[i-1] = 'E';

	fwrite((char *)&user,sizeof(user),1,qbbsfile);

// exitinfo
	
	memcpy(x,pcbsys.connectrate,5);
	x[5] = 0x00;
	exitrec.baudrate = atoi(x);

	exitrec.netmailentered = 0;
	exitrec.echomailentered = 0;

	memcpy(&exitrec.logintime[1],pcbsys.logonhhmm,5);
	exitrec.logintime[0] = 5;

	_strdate(today);
	exitrec.logindate[0] = 8;
	exitrec.logindate[3] = '-';
	exitrec.logindate[6] = '-';
	exitrec.logindate[1] = today[0];
	exitrec.logindate[2] = today[1];
	exitrec.logindate[4] = today[3];
	exitrec.logindate[5] = today[4];
	exitrec.logindate[7] = today[6];
	exitrec.logindate[8] = today[7];

	fmsbintoieee(&pcbsys.allowedseconds,&allowed);
	fmsbintoieee(&pcbsys.exitedseconds,&exited);
	fmsbintoieee(&pcbsys.logonseconds,&logon);

	exitrec.tmlimit = (allowed - (exited - logon))/60 - 1 ;

	putenv("TZ=PST");
	tzset();
	time(&long_time);
	newtime = localtime(&long_time);
	memcpy(&midnite,newtime,sizeof(*newtime));
	memcpy(&timenow,newtime,sizeof(*newtime));
	midnite.tm_sec = 0;
	midnite.tm_min = 0;
	midnite.tm_hour = 0;
	secsnow = mktime(&timenow);
	secsthen = mktime(&midnite);
	exitrec.loginsec = difftime(secsnow,secsthen);

	exitrec.credit = 0l;
	exitrec.userrecnum = 0;
	exitrec.readthru = 0;
	exitrec.pagetimes = 0;
	exitrec.downlimit = 0;

	sysinfo.callcount = 0l;
	memcpy(sysinfo.lastcaller,"",0);
	sysinfo.lastcaller[0] = 0;
	for (i = 0; i < 8; i++)
		sysinfo.extraspace[i] = 'x';

	memcpy(timelog.startdate,"",0);
	timelog.startdate[0] = 0;
	for (i = 0; i <= 23; i++)
		timelog.busyperhour[i] = ' ';
	for (i = 0; i <= 6; i++)
		timelog.busyperday[i] = ' ';

	event.status = 0;
	memcpy(&event.runtime[1],"",0);
	event.runtime[0] = 0;
	event.errorlevel = 0;
	event.days = 0;
	event.forced = 0;
	memcpy(&event.lasttimerun[1],"",0);
	event.lasttimerun[0] = 0;

	exitrec.sysinfo	 = sysinfo;
	exitrec.timelog	 = timelog;
	exitrec.user		 = user;
	exitrec.event	 = event;
	
	fwrite((char *)&exitrec,sizeof(exitrec),1,exitfile);

}


void initialize(argc,argv)
	int		argc;
	char	*argv[];


{
	char	i;

	if (argc != 4){
		printf("\nThe proper usage is:\n\n");
		printf("     pcb2qbbs <pcboard.sys> <users.bbs> <exitinfo.bbs>\n\n");
		printf("Where <pcboard.sys> is the drive and path of the pcboard.sys you want to\n");
		printf("convert,(for instance \\pcb\\pcboard.sys), and <users.bbs> and <exitinfo.bbs>\n");
		printf("are the drive and path of the quickbbs users and exitinfo files respectively.\n\n");
		exit(1);
	}

	if ((pcbfile = fopen(argv[1],"rb")) == NULL) {
		printf("can't open %s, not writing %s\n\n",argv[1],argv[2]);
		abort();
	}

	fread((char *)&pcbsys,sizeof(pcbsys),1,pcbfile);

	if ((qbbsfile = fopen(argv[2],"wb")) == NULL) {
		printf("can't open %s",argv[2]);
		abort();
	}

	if ((exitfile = fopen(argv[3],"wb")) == NULL) {
      printf("can't open %s",argv[3]);
      abort();
	}

	for (i = 0; i < 4; i++)
	     userflag[i] = 0;

}   /*  initialize  */


void terminate(argc, argv)
	int		argc;
	char	*argv[];

{
	fclose(pcbfile);
	fclose(qbbsfile);
	fclose(exitfile);
	printf("%s and %s written for %s\n",argv[2],argv[3],argv[1]);
}


int main(argc, argv)
	int		argc;
	char	*argv[];

{	initialize(argc,argv);
	writeqbbsdata();
	terminate(argc,argv);
}
